==> aws-cdk.aws-codecommit-1.135.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_codecommit_RepositoryEventTrigger(p) {
}
function _aws_cdk_aws_codecommit_RepositoryNotificationEvents(p) {
}
function _aws_cdk_aws_codecommit_RepositoryProps(p) {
}
function _aws_cdk_aws_codecommit_ReferenceEvent(p) {
}
function _aws_cdk_aws_codecommit_OnCommitOptions(p) {
}
function _aws_cdk_aws_codecommit_RepositoryTriggerOptions(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.events))
        _aws_cdk_aws_codecommit_RepositoryEventTrigger(p.events);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_codecommit_RepositoryNotifyOnOptions(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.events))
        _aws_cdk_aws_codecommit_RepositoryNotificationEvents(p.events);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_codecommit_CfnRepositoryProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.code))
        _aws_cdk_aws_codecommit_CfnRepository_CodeProperty(p.code);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_codecommit_CfnRepository(p) {
}
function _aws_cdk_aws_codecommit_CfnRepository_S3Property(p) {
}
function _aws_cdk_aws_codecommit_CfnRepository_RepositoryTriggerProperty(p) {
}
function _aws_cdk_aws_codecommit_CfnRepository_CodeProperty(p) {
}
function _aws_cdk_aws_codecommit_IRepository(p) {
}
function _aws_cdk_aws_codecommit_Repository(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_codecommit_RepositoryEventTrigger, _aws_cdk_aws_codecommit_RepositoryNotificationEvents, _aws_cdk_aws_codecommit_RepositoryProps, _aws_cdk_aws_codecommit_ReferenceEvent, _aws_cdk_aws_codecommit_OnCommitOptions, _aws_cdk_aws_codecommit_RepositoryTriggerOptions, _aws_cdk_aws_codecommit_RepositoryNotifyOnOptions, _aws_cdk_aws_codecommit_CfnRepositoryProps, _aws_cdk_aws_codecommit_CfnRepository, _aws_cdk_aws_codecommit_CfnRepository_S3Property, _aws_cdk_aws_codecommit_CfnRepository_RepositoryTriggerProperty, _aws_cdk_aws_codecommit_CfnRepository_CodeProperty, _aws_cdk_aws_codecommit_IRepository, _aws_cdk_aws_codecommit_Repository };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-codecommit-1.142.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_codecommit_RepositoryEventTrigger(p) {
}
function _aws_cdk_aws_codecommit_RepositoryNotificationEvents(p) {
}
function _aws_cdk_aws_codecommit_ReferenceEvent(p) {
}
function _aws_cdk_aws_codecommit_OnCommitOptions(p) {
}
function _aws_cdk_aws_codecommit_CodeConfig(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.code))
        _aws_cdk_aws_codecommit_CfnRepository_CodeProperty(p.code);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_codecommit_RepositoryTriggerOptions(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.events))
        _aws_cdk_aws_codecommit_RepositoryEventTrigger(p.events);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_codecommit_RepositoryProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.code))
        _aws_cdk_aws_codecommit_Code(p.code);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_codecommit_RepositoryNotifyOnOptions(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.events))
        _aws_cdk_aws_codecommit_RepositoryNotificationEvents(p.events);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_codecommit_Code(p) {
}
function _aws_cdk_aws_codecommit_CfnRepositoryProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.code))
        _aws_cdk_aws_codecommit_CfnRepository_CodeProperty(p.code);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_codecommit_CfnRepository(p) {
}
function _aws_cdk_aws_codecommit_CfnRepository_S3Property(p) {
}
function _aws_cdk_aws_codecommit_CfnRepository_RepositoryTriggerProperty(p) {
}
function _aws_cdk_aws_codecommit_CfnRepository_CodeProperty(p) {
}
function _aws_cdk_aws_codecommit_IRepository(p) {
}
function _aws_cdk_aws_codecommit_Repository(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_codecommit_RepositoryEventTrigger, _aws_cdk_aws_codecommit_RepositoryNotificationEvents, _aws_cdk_aws_codecommit_ReferenceEvent, _aws_cdk_aws_codecommit_OnCommitOptions, _aws_cdk_aws_codecommit_CodeConfig, _aws_cdk_aws_codecommit_RepositoryTriggerOptions, _aws_cdk_aws_codecommit_RepositoryProps, _aws_cdk_aws_codecommit_RepositoryNotifyOnOptions, _aws_cdk_aws_codecommit_Code, _aws_cdk_aws_codecommit_CfnRepositoryProps, _aws_cdk_aws_codecommit_CfnRepository, _aws_cdk_aws_codecommit_CfnRepository_S3Property, _aws_cdk_aws_codecommit_CfnRepository_RepositoryTriggerProperty, _aws_cdk_aws_codecommit_CfnRepository_CodeProperty, _aws_cdk_aws_codecommit_IRepository, _aws_cdk_aws_codecommit_Repository };
module.exports.DeprecationError = DeprecationError;
